#
# spec file for package qrencode
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 4
Name:           qrencode
Version:        4.1.1
Release:        150600.1.4
Summary:        C library for encoding data in a QR Code symbol
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/fukuchi/libqrencode
Source0:        https://fukuchi.org/works/qrencode/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRequires:  cmake >= 3.1.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpng)

%description
Libqrencode is a C library for encoding data in a QR Code symbol, a kind of 2D
symbology that can be scanned by handy terminals such as a mobile phone with
CCD. The capacity of QR Code is up to 7000 digits or 4000 characters, and is
highly robust.

%package -n libqrencode%{so_ver}
Summary:        C library for encoding data in a QR Code symbol
Group:          System/Libraries

%description -n libqrencode%{so_ver}
Libqrencode is a C library for encoding data in a QR Code symbol, a kind of 2D
symbology that can be scanned by handy terminals such as a mobile phone with
CCD. The capacity of QR Code is up to 7000 digits or 4000 characters, and is
highly robust.

%package devel
Summary:        C library for encoding data in a QR Code symbol - Development files
Group:          Development/Libraries/C and C++
Requires:       libqrencode%{so_ver} = %{version}

%description devel
Libqrencode is a C library for encoding data in a QR Code symbol, a kind of 2D
symbology that can be scanned by handy terminals such as a mobile phone with
CCD. The capacity of QR Code is up to 7000 digits or 4000 characters, and is
highly robust.

This package contains the development files for libqrencode.

%prep
%setup -q

%build
%cmake -DBUILD_SHARED_LIBS=TRUE
%make_jobs

%install
%cmake_install

%post -n libqrencode%{so_ver} -p /sbin/ldconfig
%postun -n libqrencode%{so_ver} -p /sbin/ldconfig

%files
%license COPYING
%doc README TODO NEWS ChangeLog
%{_mandir}/man1/qrencode.1%{ext_man}
%{_bindir}/qrencode

%files -n libqrencode%{so_ver}
%{_libdir}/libqrencode.so.%{so_ver}*

%files devel
%{_includedir}/qrencode.h
%{_libdir}/libqrencode.so
%{_libdir}/pkgconfig/libqrencode.pc

%changelog
* Thu Oct 15 2020 dmueller@suse.com
- update to 4.1.1 (jsc#PED-7296):
  * Some minor bugs in Micro QR Code generation have been fixed.
  * The data capacity calculations are now correct. These bugs probably did not
    affect the Micro QR Code generation.
* Sat Sep 12 2020 dmueller@suse.com
- update to 4.1.0:
  * Command line tool "qrencode" has been improved:
  * New option "--inline" has been added. (Thanks to @jp-bennett)
  * New option "--strict-version" has been added.
  * UTF8 mode now supports ANSI256 color. (Thanks to András Veres-
    Szentkirályi)
  * Micro QR Code no longer requires to specify the version number.
  * 'make check' allows to run the test programs. (Thanks to Jan Tojnar)
  * Some compile time warnings have been fixed.
  * Various CMake support improvements. (Thanks to @mgorny and @sdf5)
  * Some minor bug fixes. (Thanks to Lonnie Abelbeck and Frédéric Wang)
  * Some documentation/manpage improvements. (Thanks to Dan Jacobson)
  * Some performance improvements. (Thanks to @4061N and Mika Lindqvist)
- remove qrencode-fix-installation.patch (upstream)
* Fri Sep  6 2019 aloisio@gmx.com
- Update to version 4.0.2
  * Build script fixes. (Thanks to @mgorny)
  version 4.0.1
  * CMake support improved.
  * New test scripts have been added.
  * Some compile time warnings have been fixed.
- Refreshed qrencode-fix-installation.patch
* Wed Jan 24 2018 christophe@krop.fr
- Update to 4.0.0
  * EPS output now supports foreground and background color
  * XPM and PNG32 support added
  * CMake support added
  * Various bugs and performance fixes
- Add qrencode-fix-installation.patch. Fixes installation for x86_64
  targets.
* Tue Jul 18 2017 tchvatal@suse.com
- Switch to github as an url so people can see the progress
  * web is not really up-to-date
- Remove compat support for sle11
* Fri Oct  3 2014 cgiboudeaux@gmx.com
- Update to 3.4.4
  * Bugfix release. See the changelog file for the list of changes.
  * New option "--verbose" has been added to the command line tool.
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf, needed for kdebase4-workspace-libs-32bit
* Sat Nov 16 2013 asterios.dramis@gmail.com
- Update to 3.4.3:
  * New option "--rle" has been added to the command line tool.
  * Bug fixes in the library and command line tool.
* Fri Jul 26 2013 asterios.dramis@gmail.com
- Update to 3.4.2:
  * Memory leak bug has been fixed.
  * Micro QR Code encoding bug has been fixed.
  * String splitting has been improved.
- Removed qrencode-libpng16.patch (fixed upstream).
* Fri Feb 15 2013 pgajdos@suse.com
- build also against libpng16
  * libpng16.patch
* Sun Nov 25 2012 cgiboudeaux@gmx.com
- Fix the SLES build:
  * Replace 'pkgconfig(libpng)'
  * Replace %%make_install
  * BuildRequires: pkg-config
* Thu Nov  8 2012 cgiboudeaux@gmx.com
- Update to 3.4.1
  * A bug that mutual exclusion was not performed has been fixed
  * Colored QR Code support
  * SVG, UTF8, and ANSIUTF8 output supports have been added to the command line tool.
* Tue Oct 16 2012 fcrozat@suse.com
- Remove buildrequires on libSDL-devel, only required when running
  autoreconf, which is not needed at all now.
* Fri Sep 21 2012 fcrozat@suse.com
- Update to 3.3.1:
  + various bug fixes in cli, manual, configure and libtool files.
- Changes from 3.3.0:
  +  EPS, ANSI, and ASCII text output supports have been added.
  +  QRcode_APIVersion() and QRcode_APIVersionString() have been
    added.
- Changes from 3.2.1:
  + bug fixes in configure/libtool.
* Sat Apr 14 2012 dmueller@suse.com
- fix build with older distros
* Sun Jan  1 2012 cgiboudeaux@gmx.com
- Update to 3.2.0
  * Fixed a bug in mask evaluation function.
  * Micro QR Code support is now marked as "experimental" explicitly.
  * Build system fixes
  * Changes over 3.1.1. See the Changelog file
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun May  8 2011 cgiboudeaux@gmx.com
- Add qrencode
